import { CommonModule } from '@angular/common';
import { Component } from '@angular/core';
import {
  ModalController,
  IonHeader, IonNote, IonChip, IonToolbar, IonTitle, IonButtons, IonButton, IonIcon,
  IonContent, IonCard, IonCardHeader, IonCardTitle, IonCardSubtitle,
  IonCardContent, IonProgressBar, IonGrid, IonRow, IonCol, IonListHeader,
  IonLabel, IonList, IonItem, IonAvatar, IonBadge, IonFab, IonFabButton, IonSkeletonText
} from '@ionic/angular/standalone';
import { addIcons } from 'ionicons';
import {
  notificationsOutline, calendarNumber, checkmarkCircle, ellipseOutline,
  timeOutline, barbell, body, walk, add, refresh, fitness,
  flame, bicycle, trophy, ellipsisHorizontal, footsteps, footstepsOutline, chatbubbleEllipses, barChartOutline, calendarClearOutline, star, checkmarkCircleOutline, trashOutline } from 'ionicons/icons';

// 引用fmode-ng智能体组件
import { ChatPanelOptions, FmodeChat, FmodeChatMessage, openChatPanelModal } from 'fmode-ng';
import Parse from "parse";
import { CloudObject, CloudQuery, CloudUser } from 'src/lib/ncloud';
import { AlertController,ToastController } from '@ionic/angular';
// 导入计划创建模态框组件
import { PlanCreationModalComponent } from './plan-creation-modal.component';

@Component({
  selector: 'app-tab2',
  templateUrl: 'tab2.page.html',
  styleUrls: ['tab2.page.scss'],
  providers: [AlertController],
  standalone: true,
  imports: [
    CommonModule,
    IonNote, IonChip,
    IonHeader, IonToolbar, IonTitle, IonButtons, IonButton, IonIcon,
    IonContent, IonCard, IonCardHeader, IonCardTitle, IonCardSubtitle,
    IonCardContent, IonProgressBar, IonGrid, IonRow, IonCol, IonListHeader,
    IonLabel, IonList, IonItem, IonAvatar, IonBadge, IonFab, IonFabButton, IonSkeletonText
  ]
})
export class Tab2Page {

  openConsult(chatId?: string) {
    localStorage.setItem("company", "E4KpGvTEto")
    let options: ChatPanelOptions = {
      roleId: "2DXJkRsjXK", // 预设，无需更改
      onChatInit: (chat: FmodeChat) => {
       
        chat.role.set("name", "陈驰");
        chat.role.set("title", "跑步教练");
        chat.role.set("desc", "前马拉松运动员，10年跑步训练经验");
        chat.role.set("tags", ['长跑', '间歇训练', '跑姿矫正']);
        chat.role.set("avatar", "/assets/avatars/runner-coach.jpg");
        
     
        chat.role.set("prompt", `
# 角色设定
您是专业跑步教练陈驰，35岁，前国家马拉松队员。专注于跑步技术、训练计划和伤病预防。
`);
        
       
        const promptCates = [
          { img: "/assets/icon/distance.png", name: "长跑训练" },
          { img: "/assets/icon/speed.png", name: "速度提升" },
          { img: "/assets/icon/injury.png", name: "伤痛预防" }
        ];
        
        
        const promptList = [
          {
            cate: "长跑训练",
            img: "/assets/icon/distance.png",
            messageList: [
              "如何准备半程马拉松？",
              "长跑时如何合理分配体力？",
              "LSD训练的最佳距离是多少？",
              "如何提高跑步耐力？",
              "马拉松比赛补给策略"
            ]
          },
          {
            cate: "速度提升",
            img: "/assets/icon/speed.png",
            messageList: [
              "如何提升5公里跑成绩？",
              "间歇训练应该怎么安排？",
              "如何避免跑步速度平台期？",
              "步频和步幅如何优化？",
              "上坡跑训练技巧"
            ]
          },
          {
            cate: "伤痛预防",
            img: "/assets/icon/injury.png",
            messageList: [
              "跑步膝盖疼怎么恢复？",
              "如何预防跑步中的拉伤？",
              "跑后拉伸的正确方法",
              "足底筋膜炎如何缓解？",
              "跑步鞋的选择技巧"
            ]
          },
        ];
        
        let ChatPrompt = Parse.Object.extend("ChatPrompt");
        setTimeout(() => {
          chat.role.set("promptCates", promptCates);
          chat.promptList = promptList.map(item => {
            let prompt = new ChatPrompt();
            prompt.set(item);
            prompt.img = item.img;
            return prompt;
          });
        }, 500);

        // 功能按钮区域预设
        chat.leftButtons = [
          { 
            title: "话题灵感",
            showTitle: true,
            icon: "color-wand-outline",
            onClick: () => {
              chat.isPromptModalOpen = true;
            },
            show: () => chat?.promptList?.length > 0
          },
        ];
      },
      onMessage: (chat: FmodeChat, message: FmodeChatMessage) => {
        console.log("onMessage", message);
        let content: any = message?.content;
        if (typeof content === "string") {
          if (content.includes('[导诊完成]')) {
            console.log('进入问诊环节');
          } else if (content.includes('[问诊完成]')) {
            console.log('进入检查环节');
          } else if (content.includes('[检查完成]')) {
            console.log('进入诊断与处方环节');
          } else if (content.includes('[处方完成]')) {
            console.log('结束会话');
          }
        }
      },
      onChatSaved: (chat: FmodeChat) => {
        console.log("onChatSaved", chat?.chatSession?.id);
      }
    };
    openChatPanelModal(this.modalCtrl, options);
  }

  constructor(
    private modalCtrl: ModalController,
    private alertCtrl: AlertController,
    private toastCtrl: ToastController
  ) {
    addIcons({notificationsOutline,calendarNumber,refresh,barChartOutline,timeOutline,footsteps,trashOutline,calendarClearOutline,add,star,checkmarkCircleOutline,chatbubbleEllipses,checkmarkCircle,ellipseOutline,barbell,body,walk,fitness,flame,bicycle,trophy,ellipsisHorizontal,footstepsOutline});
    
    // 初始化周数据
    this.weekDays = this.generateWeekDays();
  }

  // 计算属性
  get completedWorkouts(): number {
    return this.weekDays.filter(day => day.trained).length;
  }

  get totalWorkouts(): number {
    return this.weekDays.length;
  }

  get completionRate(): number {
    return this.completedWorkouts > 0 ? this.completedWorkouts / this.totalWorkouts : 0;
  }

  // 推荐计划
  recommendedPlans = [
    {
      name: '5公里入门计划',
      duration: 28,
      difficulty: '初级',
      icon: 'footsteps',
      isNew: true
    },
    {
      name: '半马提升训练',
      duration: 35,
      difficulty: '中级',
      icon: 'footstepsOutline',
      isNew: false
    },
    {
      name: '全马备战计划',
      duration: 20,
      difficulty: '高级',
      icon: 'footsteps',
      isNew: true
    }
  ];

  // 动态加载数据
  async ngOnInit() {
    await this.loadUserData();
  }
  
  isLoading = true;
  currentUser: CloudUser | null = null;
  myPlans: any[] = [];
  
  // 使用字典存储计划任务
  planTasksMap: { [planId: string]: any[] } = {};

  // 动态生成周数据
  weekDays: any[] = [];
  generateWeekDays() {
    const days = ['周日', '周一', '周二', '周三', '周四', '周五', '周六'];
    const today = new Date().getDay(); // 0-6 (0=周日)
    
    return days.map((name, index) => ({
      shortName: name,
      name: days[index],
      trained: Math.random() > 0.5, // 模拟数据，实际应从API获取
      active: index === today
    }));
  }

  async loadUserData() {
    this.isLoading = true;

    try {
      // 获取当前用户
      this.currentUser = new CloudUser();

      if (this.currentUser.id) {
        // 加载用户的训练计划
        await this.loadTrainingPlans();
      }
    } catch (error) {
      console.error('加载用户数据失败:', error);
    } finally {
      this.isLoading = false;
    }
  }

  async loadTrainingPlans() {
    if (!this.currentUser?.id) return;
  
    try {
      const query = new CloudQuery('TrainingPlan');
      query.equalTo('user', this.currentUser.toPointer());
      
      // 确保只加载属于当前用户的计划
      const plans = await query.find();
      
      this.myPlans = plans.map(plan => ({
        id: plan.id,
        name: plan.get('planName') || '未命名计划',
        progress: this.calculatePlanProgress(plan),
        nextTime: this.getNextTrainingTime(plan),
        remaining: this.getRemainingDays(plan),
        icon: this.getPlanIcon(plan.get('fitnessGoals')),
        description: plan.get('description'),
        durationInWeeks: plan.get('durationInWeeks'),
        difficultyLevel: plan.get('difficultyLevel'),
        startDate: plan.get('startDate') // 添加起始日期
      }));
  
      // 加载每个计划的任务
      for (const plan of plans) {
        if (typeof plan.id === "string") {
          await this.loadPlanTasks(plan.id);
        }
      }
    } catch (error) {
      console.error('加载训练计划失败:', error);
      this.showToast('加载训练计划失败，请重试');
    }
  }

  async confirmDelete(event: Event, plan: any) {
    event.stopPropagation(); // 阻止事件冒泡
    
    const alert = await this.alertCtrl.create({
      header: '确认删除',
      message: `确定要删除「${plan.name}」训练计划吗？此操作不可撤销！`,
      cssClass: 'delete-confirm-alert',
      buttons: [
        {
          text: '取消',
          role: 'cancel',
          cssClass: 'cancel-btn'
        },
        {
          text: '删除',
          cssClass: 'delete-btn',
          handler: () => {
            this.deletePlan(plan);
          }
        }
      ]
    });
    
    await alert.present();
  }

  async deletePlan(plan: any) {
    try {
      // 创建CloudObject实例
      const planObj = new CloudObject('TrainingPlan');
      planObj.id = plan.id;
      
      // 显示加载状态
      const loadingAlert = await this.alertCtrl.create({
        message: '正在删除计划...',
        backdropDismiss: false,
        cssClass: 'deleting-alert'
      });
      await loadingAlert.present();
      
      // 调用destroy方法删除计划
      const success = await planObj.destroy();
      
      // 关闭加载提示
      await loadingAlert.dismiss();
      
      if (success) {
        // 更新前端列表
        this.myPlans = this.myPlans.filter(p => p.id !== plan.id);
        
        // 使用 Toast 显示成功消息（支持 duration）
        const toast = await this.toastCtrl.create({
          message: '计划已成功删除！',
          duration: 2000,
          cssClass: 'delete-success-toast',
          position: 'top'
        });
        await toast.present();
      } else {
        throw new Error('删除失败');
      }
    } catch (error: any) {
      console.error('删除计划时出错:', error);
      
      // 显示错误提示
      const errorAlert = await this.alertCtrl.create({
        header: '删除失败',
        message: error.message || '计划删除失败，请稍后重试',
        buttons: ['确定'],
        cssClass: 'delete-error-alert'
      });
      await errorAlert.present();
    }
  }

  async loadPlanTasks(planId: string) {
    const query = new CloudQuery('TrainingTask');
    query.equalTo('plan', planId);

    const tasks = await query.find();
    this.planTasksMap[planId] = tasks;
  }

  // 获取某个计划的任务
  getPlanTasks(planId: string): any[] {
    return this.planTasksMap[planId] || [];
  }

  // 计算计划进度
  calculatePlanProgress(plan: CloudObject): number {
    const tasks = this.getPlanTasks(plan.id as string);
    if (!tasks.length) return 0;
    
    const completed = tasks.filter(task => task.get('isCompleted')).length;
    return Math.round((completed / tasks.length) * 100);
  }

  getNextTrainingTime(plan: CloudObject): string {
    // 模拟实现 - 实际应根据计划schedule计算
    const days = ['明天', '后天', '大后天'];
    const times = ['7:00', '8:30', '18:00'];
    return `${days[Math.floor(Math.random() * days.length)]} ${times[Math.floor(Math.random() * times.length)]}`;
  }

  getRemainingDays(plan: CloudObject): number {
    const startDate = plan.get('startDate');
    if (!startDate) return 0;
    
    const endDate = new Date(startDate);
    const weeks = plan.get('durationInWeeks') || 4;
    endDate.setDate(endDate.getDate() + weeks * 7);
    
    const today = new Date();
    const diffInTime = endDate.getTime() - today.getTime();
    return Math.ceil(diffInTime / (1000 * 3600 * 24));
  }

  getPlanIcon(goals: string[] = []): string {
    if (goals.includes('跑步') || goals.includes('耐力')) return 'footsteps';
    if (goals.includes('减脂')) return 'flame';
    if (goals.includes('增肌')) return 'barbell';
    return 'fitness';
  }

  async refreshPlans() {
    // 重置任务映射
    this.planTasksMap = {};
    await this.loadUserData();
  }

  openPlan(plan: any) {
    console.log('打开计划:', plan);
    // 实际应用中这里应该导航到计划详情页
    // 可以传递 plan 和 this.getPlanTasks(plan.id)
  }

  // 创建新计划方法
  async createNewPlan() {
    const modal = await this.modalCtrl.create({
      component: PlanCreationModalComponent,
      breakpoints: [0, 0.5, 0.8],
      initialBreakpoint: 0.8
    });
    
    await modal.present();
    
    const { data } = await modal.onWillDismiss();
    
    if (data) {
      await this.saveNewPlan(data);
      await this.refreshPlans();
    }
  }

  // 保存新计划
  async saveNewPlan(planData: any) {
    try {
      if (!this.currentUser || !this.currentUser.id) {
        throw new Error('用户未登录，无法创建计划');
      }
  
      const newPlan = new CloudObject('TrainingPlan');
      
      // 确保日期格式正确
      const startDate = planData.startDate;
      const formattedDate = startDate ? startDate : new Date().toISOString();
      
      newPlan.set({
        planName: planData.name,
        description: planData.description,
        durationInWeeks: parseInt(planData.duration),
        difficultyLevel: planData.difficulty,
        fitnessGoals: planData.goals,
        user: this.currentUser.toPointer(),
        startDate: formattedDate
      });
      
      await newPlan.save();
      this.showToast('计划创建成功！');
    } catch (error: any) {
      console.error('创建计划失败:', error);
      this.showToast(error.message || '创建计划失败，请重试');
    }
  }
  // 显示Toast消息
  async showToast(message: string) {
    // 实际项目中应该使用Ionic的ToastController
    // 这里简化实现为alert
    alert(message);
  }
   // 根据难度级别获取徽章颜色
   getBadgeColor(difficulty: string): string {
    return difficulty.toLowerCase() + '-badge';
  }

  // 获取难度文本
  getDifficultyText(difficulty: string): string {
    const map: Record<string, string> = {
      'beginner': '初级',
      'intermediate': '中级',
      'advanced': '高级'
    };
    return map[difficulty.toLowerCase()] || difficulty;
  }

  // 根据计划难度获取卡片颜色
  getPlanColor(difficulty: string): string {
    const map: Record<string, string> = {
      'beginner': 'linear-gradient(to right, #27ae60, #2ecc71)',
      'intermediate': 'linear-gradient(to right, #f39c12, #f1c40f)',
      'advanced': 'linear-gradient(to right, #e74c3c, #c0392b)'
    };
    return map[difficulty.toLowerCase()] || '#3a7bd5';
  }

  // 获取任务标签颜色
  getChipColor(difficulty: string): string {
    const map: Record<string, string> = {
      'beginner': 'success',
      'intermediate': 'warning',
      'advanced': 'danger'
    };
    return map[difficulty.toLowerCase()] || 'primary';
  }
}